import { OnInit, EventEmitter, SimpleChanges, OnChanges } from '@angular/core';
import { IChatListDetail } from '../dto/ichat-list-detail';
import { IChatDetail } from '../dto/ichat-detail';
/**
 * Chat component por el cual mostramos una lista de chat y una conversacion
 */
export declare class ChatComponent implements OnInit, OnChanges {
    /**
     * Lista de conversaciones a mostrar
     */
    list: IChatListDetail[];
    /**
     * Conversacion actual a mostrar puede no estar en la lista
     */
    chatDetail: IChatDetail;
    /**
     * Se envia un evento si se escribio un nuevo mensaje
     */
    messageNew: EventEmitter<any>;
    /**
     * Si hace click en una conversacion de la lista
     */
    listClick: EventEmitter<any>;
    /**
     * Si elimina la conversacion
     */
    chatDelete: EventEmitter<any>;
    /**
     * Si bloquea una conversacion
     */
    chatLock: EventEmitter<any>;
    /**
     * Variable en la cual se guardara la lista ingresada o la de busqueda
     */
    finalList: IChatListDetail[];
    /**
     * Variable en la cual se guardara la lista de busqueda
     */
    searchList: IChatListDetail[];
    /**
     * Flag que nos dira si hay una busqueda o no
     */
    searchFlag: boolean;
    /**
     * Texto a buscar
     */
    searchText: string;
    /**
     * Variable en la cual tenemos la posicion del mensaje y se envia chat detail
     */
    moveToMessageIndex: number;
    /**
     * Variable en la cual tenemos la posicion del mensaje encontrado
     * mientras no se cambie de chat no se actualizara la principal
     */
    moveToMessageIndexTem: number;
    /**
     * @ignore
     */
    constructor();
    /**
     * @ignore
     */
    ngOnInit(): void;
    /**
     * 1.- si el chat que se esta mostrando a cambiado sus mensajes
     * 2.- si existe una lista de busqued
     * @param changes Si cambia algun item de la lista se actualizara
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Si hay una busqueda activa no se actualiza la lista
     */
    searchValidate(): void;
    /**
     * Si realiza un click en un item de la lista del chat cambiamos la conversacion
     * y emitimos un evento
     * @param detalle propiedades de la conversacion
     */
    listDetailClick(detalle: IChatListDetail): void;
    /**
     * Cambiamos conversacion actual y muestra la conversacion que tiene la lista por el usuario
     * @param detalle  propiedades de la conversacion
     */
    changeDetail(detail: IChatListDetail): void;
    /**
     * Cuando el usuario envie un mensaje añadimos propiedad a la lista y realizamos un push
     * @param mensaje propiedades del mensaje enviado
     */
    messageSend(mensaje: any): void;
    /**
     * Al eliminar mensajes emitiremos un evento y limpiaremos elementos
     */
    messageDelete(): void;
    /**
     * Accion de bloquear chat
     * @param estadoBloqueo los estados pueden ser desbloqueado, bloqueado, bloqueo
     */
    chatLocking(estadoBloqueo: any): void;
    /**
     * Comprobar si debe realizar una busqueda o no
     */
    searchChange(text: string): void;
    /**
     * Buscamos en la lista actual en los nombres del chat
     * @param text palabra a buscar
     */
    searchChatName(text: string): void;
    /**
     * Buscamos en la lista actual los mensajes del chat y cambiamos el ultimo chat por el chat encontrado
     * @param text palabra a buscar
     */
    searchChatMessage(text: string): void;
    /**
     * Limpiamos la lista de busqueda
     */
    searchListClean(): void;
}
